@@ -7,8 +7,8 @@ module ActiveRecord
   module VERSION
     MAJOR = 5
     MINOR = 1
-    TINY  = 6
-    PRE   = "1"
+    TINY  = 7
+    PRE   = nil
 
     STRING = [MAJOR, MINOR, TINY, PRE].compact.join(".")
   end
